# Copyright (c) 2000-2001 LOGILAB S.A. (Paris, FRANCE).
# http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
__revision__ = '$Id: Autodoc.py,v 1.10 2001/12/12 17:38:15 syt Exp $'
from narval.lib import AL_NS, NO_NS, XSL_NS, select_one

MOD_XML = '''<?xml version="1.0" encoding="ISO-8859-1"?>
<module xmlns:al="%s" name="Autodoc">''' % AL_NS

def mk_doc(args, doc, ctrl):
    # read task_ctrl structure
    ctrl_n = args['ctrl']
    try:
         group = select_one(ctrl_n, 'group/text()').data
    except:
        group = 'all'
    try:
        lang = select_one(ctrl_n, 'lang/text()').data
    except:
        lang = 'en'
    try:
        file = select_one(ctrl_n, 'file/text()').data
    except:
        file = 'file:///$NARVAL_HOME/doc/%ss-%s.%s.xml' % (ctrl, group, lang)
    doc_ctrl = doc.createElementNS(NO_NS, 'tmp-doc-ctrl')
    lang_n = doc.createElementNS(NO_NS, 'lang')
    doc_ctrl.appendChild(lang_n)
    lang_n.appendChild(doc.createTextNode(lang))
    group_n = doc.createElementNS(NO_NS, 'group')
    doc_ctrl.appendChild(group_n)
    group_n.appendChild(doc.createTextNode(group))
    url = doc.createElementNS(NO_NS, 'url')
    url.appendChild(doc.createTextNode(file))
    output = {'tmpctrl' : doc_ctrl, 'dest':url, 'output':[]}
    if group != 'all':
        if ctrl == 'xsl:transform':
            ns = XSL_NS
        else:
            ns = NO_NS
        for n in args['type']:
            if n.getAttributeNS(ns, 'group') == ctrl:
                output['output'].append(n)
    else:
        for n in args['type']:
            output['output'].append(n) 
    return output

COMMONS_IO = """
  <al:input id='ctrl' optional='yes'>
   <al:match>doc-ctrl</al:match>
   <al:description lang='en'>structure for the doc generation process's control,
   optionaly contains childs file, lang, group, which contains a text node
   respectively for: the url where the doc 'll be write (default value: $HOME/doc/{type}s-{group}.{lang}.xml),
   the language abbrev (default value: en),
   the group attributes value for filtering (default value: all, no filtering).
   </al:description>
  </al:input>
  <al:output id='tmpctrl'>  
   <al:match>tmp-doc-ctrl</al:match> 
   <al:description lang='en'>contain the required elements for documentation generation control</al:description>
  </al:output> 
  <al:output id='dest'>
   <al:match>url</al:match>
   <al:description lang='en'>the file where the documentation will be writen</al:description>
  </al:output>
"""

def filter_actions_doc_f(args, doc):
    return mk_doc(args, doc, 'al:action')
MOD_XML = MOD_XML + '''
<al:action name="filter_actions_doc" func="filter_actions_doc_f">
  <al:description lang="en">
Select actions and control structure for doc generating
  </al:description>
  <al:input id='type' list="yes">
    <al:match>al:action</al:match>
  </al:input>
  %s
  <al:output id='output' list='yes'>
   <al:match>al:action</al:match>
   <al:description lang="en">filtered actions list</al:description>
  </al:output>
</al:action>
''' % COMMONS_IO

def filter_transforms_doc_f(args, doc):
    return mk_doc(args, doc, 'xsl:transform')
MOD_XML = MOD_XML + '''
<al:action name="filter_transforms_doc" func="filter_transforms_doc_f">
  <al:description lang="en">Select transforms and control structure for doc generating</al:description>
  <al:input id='type' list="yes"><al:match>xsl:transform</al:match></al:input>
  %s
  <al:output id='output' list='yes'>
   <al:match>xsl:transform</al:match>
   <al:description lang="en">filtered transforms list</al:description>
  </al:output>
</al:action>
''' % COMMONS_IO

def filter_recipes_doc_f(args, doc):
    return mk_doc(args, doc, 'al:recipe')
MOD_XML = MOD_XML + '''
<al:action name="filter_recipes_doc" func="filter_recipes_doc_f">
  <al:description lang="en">Select recipes and control structure for doc generating</al:description>
  <al:input id='type' list="yes"><al:match>al:recipe</al:match></al:input>
  %s
  <al:output id='output' list="yes">
   <al:match>al:recipe</al:match>
   <al:description lang="en">filtered recipes list</al:description>
  </al:output>
</al:action>
''' % COMMONS_IO

MOD_XML = MOD_XML + "</module>"
